==> chrome-devtools-kotlin-0.6.0-sources.jar: org/hildan/chrome/devtools/domains/target/TargetTypes.kt <==
package org.hildan.chrome.devtools.domains.target

import kotlin.Boolean
import kotlin.Int
import kotlin.String
import kotlinx.serialization.Serializable
import org.hildan.chrome.devtools.domains.browser.BrowserContextID
import org.hildan.chrome.devtools.domains.page.FrameId
import org.hildan.chrome.devtools.protocol.ExperimentalChromeApi

/**
 *
 *
 * [Official doc](https://chromedevtools.github.io/devtools-protocol/tot/Target/#type-TargetID)
 */
public typealias TargetID = String

/**
 * Unique identifier of attached debugging session.
 *
 * [Official doc](https://chromedevtools.github.io/devtools-protocol/tot/Target/#type-SessionID)
 */
public typealias SessionID = String

/**
 *
 *
 * [Official doc](https://chromedevtools.github.io/devtools-protocol/tot/Target/#type-TargetInfo)
 */
@Serializable
public data class TargetInfo(
  public val targetId: TargetID,
  public val type: String,
  public val title: String,
  public val url: String,
  /**
   * Whether the target has an attached client.
   */
  public val attached: Boolean,
  /**
   * Opener target Id
   */
  public val openerId: TargetID? = null,
  /**
   * Whether the target has access to the originating window.
   */
  @ExperimentalChromeApi
  public val canAccessOpener: Boolean? = null,
  /**
   * Frame id of originating window (is only set if target has an opener).
   */
  @ExperimentalChromeApi
  public val openerFrameId: FrameId? = null,
  @ExperimentalChromeApi
  public val browserContextId: BrowserContextID? = null
)

/**
 *
 *
 * [Official doc](https://chromedevtools.github.io/devtools-protocol/tot/Target/#type-RemoteLocation)
 */
@ExperimentalChromeApi
@Serializable
public data class RemoteLocation(
  public val host: String,
  public val port: Int
)

==> chrome-devtools-kotlin-0.13.1-sources.jar: org/hildan/chrome/devtools/domains/target/TargetTypes.kt <==
@file:Suppress("RedundantVisibilityModifier", "DEPRECATION", "EXPERIMENTAL_API_USAGE")

package org.hildan.chrome.devtools.domains.target

import kotlin.Boolean
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlinx.serialization.Serializable
import org.hildan.chrome.devtools.domains.browser.BrowserContextID
import org.hildan.chrome.devtools.domains.page.FrameId
import org.hildan.chrome.devtools.protocol.ExperimentalChromeApi

/**
 *
 *
 * [Official doc](https://chromedevtools.github.io/devtools-protocol/tot/Target/#type-TargetID)
 */
public typealias TargetID = String

/**
 * Unique identifier of attached debugging session.
 *
 * [Official doc](https://chromedevtools.github.io/devtools-protocol/tot/Target/#type-SessionID)
 */
public typealias SessionID = String

/**
 *
 *
 * [Official doc](https://chromedevtools.github.io/devtools-protocol/tot/Target/#type-TargetInfo)
 */
@Serializable
public data class TargetInfo(
  public val targetId: TargetID,
  public val type: String,
  public val title: String,
  public val url: String,
  /**
   * Whether the target has an attached client.
   */
  public val attached: Boolean,
  /**
   * Opener target Id
   */
  public val openerId: TargetID? = null,
  /**
   * Whether the target has access to the originating window.
   */
  @ExperimentalChromeApi
  public val canAccessOpener: Boolean? = null,
  /**
   * Frame id of originating window (is only set if target has an opener).
   */
  @ExperimentalChromeApi
  public val openerFrameId: FrameId? = null,
  @ExperimentalChromeApi
  public val browserContextId: BrowserContextID? = null
)

/**
 *
 *
 * [Official doc](https://chromedevtools.github.io/devtools-protocol/tot/Target/#type-RemoteLocation)
 */
@ExperimentalChromeApi
@Serializable
public data class RemoteLocation(
  public val host: String,
  public val port: Int
)
